@@ -1,3 +1,5 @@
+from typing import Tuple
+
 from torch import matmul, nn, reshape, stack, zeros
 
 
@@ -21,7 +23,7 @@ class GANAttention(nn.Module):
     Custom Attention Module from https://github.com/AdalbertoCq/Pathology-GAN/blob/master/models/generative/ops.py (attention_block)
     """
 
-    def __init__(self, z: tuple(int, int, int), channel_divisor: int):
+    def __init__(self, z: Tuple[int, int, int], channel_divisor: int):
         """
         Init for GANGAttention
 
